Thanks for contributing to lsst-rsp.

## Support

If you are a Rubin Observatory staff member, please reach out of us on Slack in the #dm-square channel or create a Jira ticket.

If you are a community member, feel free to create a GitHub issue and we'll do our best to help you.

## Pull requests

Since lsst-rsp is built for the Vera C. Rubin Observatory and Legacy Survey of Space and Time, community contributions can only be accepted if they align with the Rubin Observatory's mission.
For that reason, it's a good idea to propose changes with a new GitHub issue before investing time in making a pull request.

* * *

See also our [Code of Conduct](./CODE_OF_CONDUCT).
